@@ -388,9 +388,14 @@ func TestLoadTOMLAppConfigReferenceFormat(t *testing.T) {
 		},
 
 		Deploy: &Deploy{
-			ReleaseCommand: "release command",
-			Strategy:       "rolling-eyes",
-			MaxUnavailable: fly.Pointer(0.2),
+			Strategy:              "rolling-eyes",
+			MaxUnavailable:        fly.Pointer(0.2),
+			ReleaseCommand:        "release command",
+			ReleaseCommandTimeout: fly.MustParseDuration("3m"),
+			ReleaseCommandCompute: &Compute{
+				Size:   "performance-2x",
+				Memory: "8g",
+			},
 		},
 
 		Env: map[string]string{
