@@ -3,6 +3,7 @@ package tokens
 import (
 	"context"
 	"fmt"
+	"time"
 
 	"github.com/spf13/cobra"
 	"github.com/superfly/flyctl/internal/appconfig"
@@ -38,6 +39,8 @@ func newList() *cobra.Command {
 		flag.Org(),
 	)
 
+	cmd.Aliases = []string{"ls"}
+
 	return cmd
 }
 
@@ -89,7 +92,7 @@ func runList(ctx context.Context) (err error) {
 
 		fmt.Fprintln(out, "Tokens for app \""+appName+"\":")
 		for _, token := range tokens {
-			rows = append(rows, []string{token.Id, token.Name, token.User.Email, token.ExpiresAt.String()})
+			rows = append(rows, []string{token.Id, token.Name, token.User.Email, token.ExpiresAt.String(), revokedAtToString(token.RevokedAt)})
 		}
 
 	case "org":
@@ -100,14 +103,21 @@ func runList(ctx context.Context) (err error) {
 
 		fmt.Fprintln(out, "Tokens for organization \""+org.Slug+"\":")
 		for _, token := range org.LimitedAccessTokens.Nodes {
-			rows = append(rows, []string{token.Id, token.Name, token.User.Email, token.ExpiresAt.String()})
+			rows = append(rows, []string{token.Id, token.Name, token.User.Email, token.ExpiresAt.String(), revokedAtToString(token.RevokedAt)})
 		}
 	}
 
-	_ = render.Table(out, "", rows, "ID", "Name", "Created By", "Expires At")
+	_ = render.Table(out, "", rows, "ID", "Name", "Created By", "Expires At", "Revoked At")
 	return nil
 }
 
+func revokedAtToString(time *time.Time) string {
+	if time != nil {
+		return time.String()
+	}
+	return ""
+}
+
 func determineScope(scopeStr string, appFlagStr string, orgFlagStr string, configFlagStr string) (scope string, err error) {
 	// app scope is given highest priority, as it is more granular than org, identified by --app|--config|--scope=app
 	// org scope is only used when specified by --org|--scope=org withought any app scope indicator
